LineNumbers

Enum LineNumbers 

pub enum LineNumbers {
    AlwaysOn,
    Enabled,
    Disabled,
    AlwaysOff,
}
Enum indicating whether to display the line numbers or not.

Note that displaying line numbers may be less performant than not doing it. minus tries to do as quickly as possible but the numbers and padding still have to be computed.

This implements Not to allow turning on/off line numbers when they where not locked in by the binary displaying the text.

Variants



AlwaysOn

Enable line numbers permanently, cannot be turned off by user.



Enabled

Line numbers should be turned on, although users can turn it off (i.e, set it to Disabled).



Disabled

Line numbers should be turned off, although users can turn it on (i.e, set it to Enabled).



AlwaysOff

Disable line numbers permanently, cannot be turned on by user.