Module error

Module error 

Provides error types that are used in various places

Some types provided are just present there to avoid leaking upstream error types

Structs

RegexErrorsearch
There was an error while compiling the regex
TermError
An operation on the terminal failed, for example resizing it.

Enums

CleanupError
Errors that can occur during clean up.
MinusError
Errors that can happen during runtime.
SetupError
Errors that can occur during setup.