dynamic_paging

Function dynamic_paging 

pub fn dynamic_paging(pager: Pager) -> Result<(), MinusError>
Available on crate feature dynamic_output only.
Starts a asynchronously running pager

This means that data and configuration can be fed into the pager while it is running.

See examples on how to use this function.

Panics

This function will panic if another instance of minus is already running.

Errors

The function will return with an error if it encounters a error during paging.