Module hooks

Module hooks 

Manages and runs callbacks for events happening in minus.

Note on Thread Blacking

Callbacks registered for hooks are run on the same thread as the pager. This means that if you add a long-running task in a callback, it will block the pager from rendering, scrolling and responding to events. Hence you should avoid adding long-running tasks in callbacks. If you have a long running task, you should run it on a separate thread.

Enums

Hook
Events that can have callbacks registered

Type Aliases

HookCallback
A callback that can be executed on a hook