pub enum Hook {
PrePagerStart,
PostPagerStart,
EofReached,
PrePagerExit,
PostPagerExit,
}Expand description
Events that can have callbacks registered
Variants
PrePagerStart
Fired just before the terminal UI is drawn (before switching to the alternate screen).
PostPagerStart
Fired after the terminal UI is drawn with text.
EofReached
Fired when the user hits the end of the page
PrePagerExit
Fired just before the pager exits due to InputEvent::Exit.
PostPagerExit
Fired after the terminal UI is cleared up and main screen is restored.
For this hook, start your IDs from 2 because 1 is occupied for the
ExitStrategy.