DefaultInputClassifier

Struct DefaultInputClassifier 

pub struct DefaultInputClassifier;
👎Deprecated:

See #163.

The default set of input definitions

This is kept only for legacy purposes and may not be well updated with all the latest changes