Module screen

Module screen 

Provides functions for getting analysis of the text data inside minus.

This module is still a work is progress and is subject to change.

Structs

Screen
Stores all the data for the terminal

Type Aliases

Line
OwnedTextBlock
Row
Rows
TextBlock