pub struct Screen { /* private fields */ }Expand description
Stores all the data for the terminal
This can be used by applications to get a basic analysis of the data that minus has captured while formattng it for terminal display.
Most of the functions of this type are cheap as minus does a lot of caching of the analysis behind the scenes
Implementations
Sourceimpl Screen
impl Screen
Sourcepub const fn formatted_lines_count(&self) -> usize
pub const fn formatted_lines_count(&self) -> usize
Get the actual number of physical rows that the text that will actually occupy on the terminal
Sourcepub const fn line_count(&self) -> usize
pub const fn line_count(&self) -> usize
Get the number of Lines in the text.
Sourcepub const fn get_max_line_length(&self) -> usize
pub const fn get_max_line_length(&self) -> usize
Get the length of the longest Line in the text.