SearchOpts

Struct SearchOpts 

pub struct SearchOpts<'a> {
    pub ev: Option<Event>,
    pub string: String,
    pub input_status: InputStatus,
    pub cursor_position: u16,
    pub search_mode: SearchMode,
    pub word_index: Vec<u16>,
    pub search_char: char,
    pub rows: u16,
    pub cols: u16,
    pub incremental_search_options: Option<IncrementalSearchOpts<'a>>,
    pub smart_case: bool,
    /* private fields */
}
Available on crate feature search only.
Options controlling the behaviour of search overall

Although it isn’t much important for most use cases but it alongside IncrementalSearchOpts are the key components when applications want to customize the incremental seaech condition.

Most of the fields have self-explanatory names so it should be very easy to get started using this

Fields

ev: Option<Event>

A crossterm Event on which to respond

string: String

Current string query

input_status: InputStatus

Status of the input prompt. See InputStatus

cursor_position: u16

Specifies the terminal column number that the cursor on at the prompt site. It can range between 1 and string.len() + 1

search_mode: SearchMode

Direction of search. See SearchMode.

word_index: Vec<u16>

Column numbers where each new word start

search_char: char

Search character, either / or ? depending on SearchMode

rows: u16

Number of rows available in the terminal

cols: u16

Number of cols available in the terminal

incremental_search_options: Option<IncrementalSearchOpts<'a>>

Options specifically controlling incremental search

smart_case: bool

Whether smart case search is enabled