PagerState

Struct PagerState 

pub struct PagerState {
Show 13 fields pub line_numbers: LineNumbers, pub message: Option<String>, pub upper_mark: usize, pub left_mark: usize, pub search_mode: SearchMode, pub rows: usize, pub cols: usize, pub prefix_num: String, pub running: &'static Mutex<RunMode>, pub search_state: SearchState, pub screen: Screen, pub selection: Option<Selection>, pub output_sink: Arc<Mutex<Box<dyn OutputSink>>>, /* private fields */
}

Fields

line_numbers: LineNumbers

Configuration for line numbers. See LineNumbers

message: Option<String>

Any message to display to the user at the prompt The first element contains the actual message, while the second element tells whether the message has changed since the last display.

upper_mark: usize

The upper bound of scrolling.

This is useful for keeping track of the range of lines which are currently being displayed on the terminal. When rows - 1 is added to the upper_mark, it gives the lower bound of scroll.

For example if there are 10 rows is a terminal and the data to display has 50 lines in it If the upper_mark is 15, then the first row of the terminal is the 16th line of the data and last row is the 24th line of the data.

left_mark: usize

The left mark of scrolling

When this is > 0, this amount of text will be truncated from the left side

search_mode: SearchMode
Available on crate feature search only.

Direction of search

See SearchMode for available options

WARNING: This item has been deprecated in favour of SearchState::search_mode availlable by the PagerState::search_state field. Any new code should prefer using it instead of this one.

rows: usize

Available rows in the terminal

cols: usize

Available columns in the terminal

prefix_num: String

This variable helps in scrolling more than one line at a time It keeps track of all the numbers that have been entered by the user until any of j, k, G, Up or Down is pressed

running: &'static Mutex<RunMode>

Describes whether minus is running and in which mode

search_state: SearchState
Available on crate feature search only.
screen: Screenselection: Option<Selection>output_sink: Arc<Mutex<Box<dyn OutputSink>>>

The output sink configured for the pager.

Implementations

Source

impl PagerState

pub const fn set_smart_case(&mut self, smart_case: bool)

Available on crate feature search only.

Enable or disable smart case searching.

When enabled, search queries containing no uppercase characters are case-insensitive, while queries containing uppercase characters remain case-sensitive.