pub enum ExitStrategy {
ProcessQuit,
PagerQuit,
}Expand description
Behaviour that happens when the pager is exited
Variants
ProcessQuit
Kill the entire application immediately.
This is the preferred option if paging is the last thing you do. For example, the last thing you do in your program is reading from a file or a database and paging it concurrently
This is the default strategy.
PagerQuit
Kill the pager only.
This is the preferred option if you want to do more stuff after exiting the pager. For example, if you’ve file system locks or you want to close database connectiions after the pager has done i’s job, you probably want to go for this option