Provides error types that are used in various places
Some types provided are just present there to avoid leaking upstream error types
Structs
- Regex
Error search - There was an error while compiling the regex
- Term
Error - An operation on the terminal failed, for example resizing it.
Enums
- Cleanup
Error - Errors that can occur during clean up.
- Minus
Error - Errors that can happen during runtime.
- Setup
Error - Errors that can occur during setup.