TermError

Struct TermError 

pub struct TermError(/* private fields */);
An operation on the terminal failed, for example resizing it.

You can get more information about this error by calling source on it.