#[non_exhaustive]pub enum InputEvent {
Show 21 variants
Exit,
UpdateTermArea(usize, usize),
UpdateUpperMark(usize),
UpdateLineNumber(LineNumbers),
Number(char),
RestorePrompt,
HorizontalScroll(bool),
UpdateLeftMark(usize),
StartSelection {
x: u16,
y: u16,
},
UpdateSelection {
x: u16,
y: u16,
},
ClearSelection,
CopySelection,
Ignore,
Search(SearchMode),
NextMatch,
PrevMatch,
MoveToNextMatch(usize),
MoveToPrevMatch(usize),
FollowOutput(bool),
ToggleSmartCase,
ShowHelp,
}Expand description
Events handled by the minus pager.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Exit
Ctrl+C or Q, exits the application.
UpdateTermArea(usize, usize)
The terminal was resized. Contains the new number of rows.
UpdateUpperMark(usize)
Sent by movement keys like Up Down, PageUp, PageDown, ‘g’, G etc.
Contains the new value for the upper mark.
UpdateLineNumber(LineNumbers)
Ctrl+L, inverts the line number display. Contains the new value.
Number(char)
A number key has been pressed. This inner value is stored as a char.
The input loop will append this number to its count string variable
RestorePrompt
Restore the original prompt
HorizontalScroll(bool)
Whether to allow Horizontal scrolling
UpdateLeftMark(usize)
Sets the left mark of Horizontal scrolling
Sent by keys like l, h, right, left etc.
StartSelection
Start a mouse selection at the given screen coordinates.
UpdateSelection
Update the current mouse selection to the given screen coordinates.
ClearSelection
Clear the current mouse selection.
CopySelection
clipboard only.Copy the current selection.
Ignore
Tells the event hadler to not do anything for this event
This is extremely useful when you want to execute arbitrary code on events without necessarily asking the event handler to do anything special for this event. See Custom Actions on User Events.
Search(SearchMode)
search only./, Searching for certain pattern of text
NextMatch
Use InputEvent::MoveToNextMatch(1) for the same effect.
search only.Get to the next match in forward mode
WARNING: This has been deprecated in favour of MoveToNextMatch. This will likely be
removed in the next major release.
PrevMatch
Use InputEvent::MoveToPrevMatch(1) for the same effect.
search only.Get to the previous match in forward mode
WARNING: This has been deprecated in favour of MoveToPrevMatch. This will likely be
removed in the next major release.
MoveToNextMatch(usize)
search only.Move to the next nth match in the given direction
MoveToPrevMatch(usize)
search only.Move to the previous nth match in the given direction
FollowOutput(bool)
Control follow mode.
When set to true, minus ensures that the user’s screen always follows the end part of the output. By default it is turned off.
This is similar to Pager::follow_output except that
this is used to control it from the user’s side.
ToggleSmartCase
search only.Toggle smart case searching mode.
ShowHelp
Show help message in the prompt area.