pub trait InputClassifier {
// Required method
fn classify_input(&self, ev: Event, ps: &PagerState) -> Option<InputEvent>;
// Provided method
fn format_help(&self) -> Option<String> { ... }
}👎Deprecated:
See #163.
Classifies the input and returns the appropriate InputEvent
If you are using the newer method for input definition, you don’t need to take care of this.
If you are using the legacy method, see the sources of DefaultInputClassifier on how to
inplement this trait.
Required Methods
fn classify_input(&self, ev: Event, ps: &PagerState) -> Option<InputEvent>
👎Deprecated:
See #163.
Provided Methods
Sourcefn format_help(&self) -> Option<String>
👎Deprecated: See #163.
fn format_help(&self) -> Option<String>
See #163.
Format dynamic help text from registered bindings, if supported.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".