pub type ClipboardHandler = Box<dyn Fn(&str) + Send + Sync + 'static>;Available on crate feature
clipboard only.Expand description
Holds all information and configuration about the pager during its run time.
This type is exposed so that end-applications can implement the
InputClassifier trait which requires the PagerState to be passed
as a parameter
Various fields are made public so that their values can be accessed while implementing the trait.
Aliased Type
pub struct ClipboardHandler(/* private fields */);